@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.35';
+$VERSION = '0.36';
 
 =head1 NAME
 
@@ -172,6 +172,8 @@ my %default = (
     mailrc      => 'data/01mailrc.txt'
 );
 
+my $sponsorfile = 'sponsors.json';
+
 my (%AUTHORS,%PREFS,@SPONSORS,$MT,$IHEART);
 
 my %MODES = (
@@ -1020,13 +1022,23 @@ sub _get_authorX {
 
 sub _load_sponsors {
     my $self = shift;
+    my $json;
 
     my $mech = WWW::Mechanize->new();
     $mech->agent_alias( 'Linux Mozilla' );
     eval { $mech->get( $IHEART ) };
-    return if($@ || !$mech->success() || !$mech->content());
 
-    my $json = $mech->content();
+    # if the network connection failed...
+    if($@ || !$mech->success() || !$mech->content()) {
+        if(-f $sponsorfile) {
+            $json = read_file($sponsorfile);
+        } else {
+            return;
+        }
+    } else {
+        $json = $mech->content();
+    }
+
     my $data = decode_json($json);
 
     return unless($data);
@@ -1047,8 +1059,11 @@ sub _load_sponsors {
         }
     }
 
-    $self->_log( "INFO: " . scalar(@SPONSORS) . " Sponsors loaded\n" );
-    $self->_log( "INFO: Sponsors: " . Dumper(\@SPONSORS) );
+    # save file in case the network connection fails
+    overwrite_file($sponsorfile, $json);
+
+    #$self->_log( "INFO: " . scalar(@SPONSORS) . " Sponsors loaded\n" );
+    #$self->_log( "INFO: Sponsors: " . Dumper(\@SPONSORS) );
 
     $MT = Math::Random::MT->new(time);
 }
@@ -1267,7 +1282,7 @@ Miss Barbell Productions, L<http://www.missbarbell.co.uk/>
 
 =head1 COPYRIGHT & LICENSE
 
-  Copyright (C) 2008-2014 Barbie for Miss Barbell Productions.
+  Copyright (C) 2008-2016 Barbie for Miss Barbell Productions.
 
   This distribution is free software; you can redistribute it and/or
   modify it under the Artistic Licence v2.
